package com.ruoyi.system.domain.system;

import java.io.Serializable;
import java.util.ArrayList;
import java.util.List;

public class SysRegionPermissionExample implements Serializable {
    protected String orderByClause;

    protected boolean distinct;

    protected List<Criteria> oredCriteria;

    private static final long serialVersionUID = 1L;

    public SysRegionPermissionExample() {
        oredCriteria = new ArrayList<Criteria>();
    }

    public void setOrderByClause(String orderByClause) {
        this.orderByClause = orderByClause;
    }

    public String getOrderByClause() {
        return orderByClause;
    }

    public void setDistinct(boolean distinct) {
        this.distinct = distinct;
    }

    public boolean isDistinct() {
        return distinct;
    }

    public List<Criteria> getOredCriteria() {
        return oredCriteria;
    }

    public void or(Criteria criteria) {
        oredCriteria.add(criteria);
    }

    public Criteria or() {
        Criteria criteria = createCriteriaInternal();
        oredCriteria.add(criteria);
        return criteria;
    }

    public Criteria createCriteria() {
        Criteria criteria = createCriteriaInternal();
        if (oredCriteria.size() == 0) {
            oredCriteria.add(criteria);
        }
        return criteria;
    }

    protected Criteria createCriteriaInternal() {
        Criteria criteria = new Criteria();
        return criteria;
    }

    public void clear() {
        oredCriteria.clear();
        orderByClause = null;
        distinct = false;
    }

    protected abstract static class GeneratedCriteria implements Serializable {
        protected List<Criterion> criteria;

        protected GeneratedCriteria() {
            super();
            criteria = new ArrayList<Criterion>();
        }

        public boolean isValid() {
            return criteria.size() > 0;
        }

        public List<Criterion> getAllCriteria() {
            return criteria;
        }

        public List<Criterion> getCriteria() {
            return criteria;
        }

        protected void addCriterion(String condition) {
            if (condition == null) {
                throw new RuntimeException("Value for condition cannot be null");
            }
            criteria.add(new Criterion(condition));
        }

        protected void addCriterion(String condition, Object value, String property) {
            if (value == null) {
                throw new RuntimeException("Value for " + property + " cannot be null");
            }
            criteria.add(new Criterion(condition, value));
        }

        protected void addCriterion(String condition, Object value1, Object value2, String property) {
            if (value1 == null || value2 == null) {
                throw new RuntimeException("Between values for " + property + " cannot be null");
            }
            criteria.add(new Criterion(condition, value1, value2));
        }

        public Criteria andIdIsNull() {
            addCriterion("id is null");
            return (Criteria) this;
        }

        public Criteria andIdIsNotNull() {
            addCriterion("id is not null");
            return (Criteria) this;
        }

        public Criteria andIdEqualTo(Long value) {
            addCriterion("id =", value, "id");
            return (Criteria) this;
        }

        public Criteria andIdNotEqualTo(Long value) {
            addCriterion("id <>", value, "id");
            return (Criteria) this;
        }

        public Criteria andIdGreaterThan(Long value) {
            addCriterion("id >", value, "id");
            return (Criteria) this;
        }

        public Criteria andIdGreaterThanOrEqualTo(Long value) {
            addCriterion("id >=", value, "id");
            return (Criteria) this;
        }

        public Criteria andIdLessThan(Long value) {
            addCriterion("id <", value, "id");
            return (Criteria) this;
        }

        public Criteria andIdLessThanOrEqualTo(Long value) {
            addCriterion("id <=", value, "id");
            return (Criteria) this;
        }

        public Criteria andIdIn(List<Long> values) {
            addCriterion("id in", values, "id");
            return (Criteria) this;
        }

        public Criteria andIdNotIn(List<Long> values) {
            addCriterion("id not in", values, "id");
            return (Criteria) this;
        }

        public Criteria andIdBetween(Long value1, Long value2) {
            addCriterion("id between", value1, value2, "id");
            return (Criteria) this;
        }

        public Criteria andIdNotBetween(Long value1, Long value2) {
            addCriterion("id not between", value1, value2, "id");
            return (Criteria) this;
        }

        public Criteria andTypeIsNull() {
            addCriterion("type is null");
            return (Criteria) this;
        }

        public Criteria andTypeIsNotNull() {
            addCriterion("type is not null");
            return (Criteria) this;
        }

        public Criteria andTypeEqualTo(String value) {
            addCriterion("type =", value, "type");
            return (Criteria) this;
        }

        public Criteria andTypeNotEqualTo(String value) {
            addCriterion("type <>", value, "type");
            return (Criteria) this;
        }

        public Criteria andTypeGreaterThan(String value) {
            addCriterion("type >", value, "type");
            return (Criteria) this;
        }

        public Criteria andTypeGreaterThanOrEqualTo(String value) {
            addCriterion("type >=", value, "type");
            return (Criteria) this;
        }

        public Criteria andTypeLessThan(String value) {
            addCriterion("type <", value, "type");
            return (Criteria) this;
        }

        public Criteria andTypeLessThanOrEqualTo(String value) {
            addCriterion("type <=", value, "type");
            return (Criteria) this;
        }

        public Criteria andTypeLike(String value) {
            addCriterion("type like", value, "type");
            return (Criteria) this;
        }

        public Criteria andTypeNotLike(String value) {
            addCriterion("type not like", value, "type");
            return (Criteria) this;
        }

        public Criteria andTypeIn(List<String> values) {
            addCriterion("type in", values, "type");
            return (Criteria) this;
        }

        public Criteria andTypeNotIn(List<String> values) {
            addCriterion("type not in", values, "type");
            return (Criteria) this;
        }

        public Criteria andTypeBetween(String value1, String value2) {
            addCriterion("type between", value1, value2, "type");
            return (Criteria) this;
        }

        public Criteria andTypeNotBetween(String value1, String value2) {
            addCriterion("type not between", value1, value2, "type");
            return (Criteria) this;
        }

        public Criteria andWgCodeIsNull() {
            addCriterion("wg_code is null");
            return (Criteria) this;
        }

        public Criteria andWgCodeIsNotNull() {
            addCriterion("wg_code is not null");
            return (Criteria) this;
        }

        public Criteria andWgCodeEqualTo(String value) {
            addCriterion("wg_code =", value, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeNotEqualTo(String value) {
            addCriterion("wg_code <>", value, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeGreaterThan(String value) {
            addCriterion("wg_code >", value, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeGreaterThanOrEqualTo(String value) {
            addCriterion("wg_code >=", value, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeLessThan(String value) {
            addCriterion("wg_code <", value, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeLessThanOrEqualTo(String value) {
            addCriterion("wg_code <=", value, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeLike(String value) {
            addCriterion("wg_code like", value, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeNotLike(String value) {
            addCriterion("wg_code not like", value, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeIn(List<String> values) {
            addCriterion("wg_code in", values, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeNotIn(List<String> values) {
            addCriterion("wg_code not in", values, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeBetween(String value1, String value2) {
            addCriterion("wg_code between", value1, value2, "wgCode");
            return (Criteria) this;
        }

        public Criteria andWgCodeNotBetween(String value1, String value2) {
            addCriterion("wg_code not between", value1, value2, "wgCode");
            return (Criteria) this;
        }

        public Criteria andForeignIdIsNull() {
            addCriterion("foreign_id is null");
            return (Criteria) this;
        }

        public Criteria andForeignIdIsNotNull() {
            addCriterion("foreign_id is not null");
            return (Criteria) this;
        }

        public Criteria andForeignIdEqualTo(String value) {
            addCriterion("foreign_id =", value, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdNotEqualTo(String value) {
            addCriterion("foreign_id <>", value, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdGreaterThan(String value) {
            addCriterion("foreign_id >", value, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdGreaterThanOrEqualTo(String value) {
            addCriterion("foreign_id >=", value, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdLessThan(String value) {
            addCriterion("foreign_id <", value, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdLessThanOrEqualTo(String value) {
            addCriterion("foreign_id <=", value, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdLike(String value) {
            addCriterion("foreign_id like", value, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdNotLike(String value) {
            addCriterion("foreign_id not like", value, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdIn(List<String> values) {
            addCriterion("foreign_id in", values, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdNotIn(List<String> values) {
            addCriterion("foreign_id not in", values, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdBetween(String value1, String value2) {
            addCriterion("foreign_id between", value1, value2, "foreignId");
            return (Criteria) this;
        }

        public Criteria andForeignIdNotBetween(String value1, String value2) {
            addCriterion("foreign_id not between", value1, value2, "foreignId");
            return (Criteria) this;
        }
    }

    public static class Criteria extends GeneratedCriteria implements Serializable {

        protected Criteria() {
            super();
        }
    }

    public static class Criterion implements Serializable {
        private String condition;

        private Object value;

        private Object secondValue;

        private boolean noValue;

        private boolean singleValue;

        private boolean betweenValue;

        private boolean listValue;

        private String typeHandler;

        public String getCondition() {
            return condition;
        }

        public Object getValue() {
            return value;
        }

        public Object getSecondValue() {
            return secondValue;
        }

        public boolean isNoValue() {
            return noValue;
        }

        public boolean isSingleValue() {
            return singleValue;
        }

        public boolean isBetweenValue() {
            return betweenValue;
        }

        public boolean isListValue() {
            return listValue;
        }

        public String getTypeHandler() {
            return typeHandler;
        }

        protected Criterion(String condition) {
            super();
            this.condition = condition;
            this.typeHandler = null;
            this.noValue = true;
        }

        protected Criterion(String condition, Object value, String typeHandler) {
            super();
            this.condition = condition;
            this.value = value;
            this.typeHandler = typeHandler;
            if (value instanceof List<?>) {
                this.listValue = true;
            } else {
                this.singleValue = true;
            }
        }

        protected Criterion(String condition, Object value) {
            this(condition, value, null);
        }

        protected Criterion(String condition, Object value, Object secondValue, String typeHandler) {
            super();
            this.condition = condition;
            this.value = value;
            this.secondValue = secondValue;
            this.typeHandler = typeHandler;
            this.betweenValue = true;
        }

        protected Criterion(String condition, Object value, Object secondValue) {
            this(condition, value, secondValue, null);
        }
    }
}